==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemFilm.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitDataComponent;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.init.InitSounds;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import javax.annotation.Nullable;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3419;
import net.minecraft.class_7923;
import net.minecraft.class_9279;
import java.util.List;
import java.util.Objects;

public class ItemFilm extends AbstractStoreMaidItem {
    private static final String ID_TAG = "id";

    public ItemFilm() {
        super((new class_1792.class_1793()).method_7889(1));
    }

    public static class_1799 maidToFilm(EntityMaid maid) {
        class_1799 film = InitItems.FILM.method_7854();
        class_2487 maidTag = new class_2487();
        maid.setHomeModeEnable(false);
        maid.method_5647(maidTag);
        removeMaidSomeData(maidTag);
        maidTag.method_10582("id", Objects.requireNonNull(class_7923.field_41177.method_10221(InitEntities.MAID)).toString());
        film.method_57379(InitDataComponent.MAID_INFO, class_9279.method_57456(maidTag));
        return film;
    }

    public static void filmToMaid(class_1799 film, class_1937 worldIn, class_2338 pos, class_1657 player) {
        class_9279 compoundData = film.method_57824(InitDataComponent.MAID_INFO);
        if (compoundData == null) {
            return;
        }
        class_2487 data = compoundData.method_57461();
        class_2960 entityId = class_2960.method_12829(data.method_10558(ID_TAG));
        class_2960 maidId = class_7923.field_41177.method_10221(InitEntities.MAID);

        if (entityId != null && entityId.equals(maidId)) {
            EntityMaid maid = new EntityMaid(worldIn);
            maid.method_5749(data);
            maid.method_5814(pos.method_10263(), pos.method_10264(), pos.method_10260());
            // 实体生成必须在服务端应用
            if (!worldIn.field_9236) {
                worldIn.method_8649(maid);
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.EXPLOSION));
                worldIn.method_8396(null, pos, InitSounds.ALTAR_CRAFT, class_3419.field_15246, 1.0f, 1.0f);
            }
            film.method_7934(1);
            return;
        }

        if (!worldIn.field_9236) {
            player.method_43496(class_2561.method_43471("tooltips.touhou_little_maid.film.no_data.desc"));
        }
    }

    private static void removeMaidSomeData(class_2487 nbt) {
        nbt.method_10551(EntityMaid.MAID_BACKPACK_TYPE);
        nbt.method_10551(EntityMaid.MAID_INVENTORY_TAG);
        nbt.method_10551(EntityMaid.MAID_BAUBLE_INVENTORY_TAG);
        nbt.method_10551(EntityMaid.EXPERIENCE_TAG);
        nbt.method_10551("ArmorItems");
        nbt.method_10551("HandItems");
        nbt.method_10551("Leash");
        nbt.method_10551("Health");
        nbt.method_10551("HurtTime");
        nbt.method_10551("DeathTime");
        nbt.method_10551("HurtByTimestamp");
        nbt.method_10551("Pos");
        nbt.method_10551("Motion");
        nbt.method_10551("FallDistance");
        nbt.method_10551("Fire");
        nbt.method_10551("Air");
        nbt.method_10551("TicksFrozen");
        nbt.method_10551("HasVisualFire");
        nbt.method_10551("Passengers");
        nbt.method_10551("ActiveEffects");
    }

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1792.class_9635 worldIn, List<class_2561> tooltip, class_1836 flagIn) {
        if (stack.method_57824(InitDataComponent.MAID_INFO) == null) {
            tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.film.no_data.desc").method_27692(class_124.field_1079));
        }
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.6-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemFilm.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import com.github.tartaricacid.touhoulittlemaid.api.event.MaidAndItemTransformEvent;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitDataComponent;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.init.InitSounds;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import javax.annotation.Nullable;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3419;
import net.minecraft.class_7923;
import net.minecraft.class_9279;
import java.util.List;
import java.util.Objects;

public class ItemFilm extends AbstractStoreMaidItem {
    private static final String ID_TAG = "id";

    public ItemFilm() {
        super((new class_1792.class_1793()).method_7889(1));
    }

    public static class_1799 maidToFilm(EntityMaid maid) {
        class_1799 film = InitItems.FILM.method_7854();
        class_2487 maidTag = new class_2487();
        maid.setHomeModeEnable(false);
        maid.method_5647(maidTag);
        removeMaidSomeData(maidTag);
        maidTag.method_10582(ID_TAG, Objects.requireNonNull(class_7923.field_41177.method_10221(InitEntities.MAID)).toString());

        var event = new MaidAndItemTransformEvent.ToItem(maid, film, maidTag);
        MaidAndItemTransformEvent.TO_ITEM.invoker().onToItem(event);

        film.method_57379(InitDataComponent.MAID_INFO, class_9279.method_57456(maidTag));
        return film;
    }

    public static void filmToMaid(class_1799 film, class_1937 worldIn, class_2338 pos, class_1657 player) {
        class_9279 compoundData = film.method_57824(InitDataComponent.MAID_INFO);
        if (compoundData == null) {
            return;
        }
        class_2487 data = compoundData.method_57461();
        class_2960 entityId = class_2960.method_12829(data.method_10558(ID_TAG));
        class_2960 maidId = class_7923.field_41177.method_10221(InitEntities.MAID);

        if (entityId != null && entityId.equals(maidId)) {
            EntityMaid maid = new EntityMaid(worldIn);

            var event = new MaidAndItemTransformEvent.ToMaid(maid, film, data);
            MaidAndItemTransformEvent.TO_MAID.invoker().onToMaid(event);

            maid.method_5749(data);
            maid.method_5814(pos.method_10263(), pos.method_10264(), pos.method_10260());
            // 实体生成必须在服务端应用
            if (!worldIn.field_9236) {
                worldIn.method_8649(maid);
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.EXPLOSION));
                worldIn.method_8396(null, pos, InitSounds.ALTAR_CRAFT, class_3419.field_15246, 1.0f, 1.0f);
            }
            film.method_7934(1);
            return;
        }

        if (!worldIn.field_9236) {
            player.method_43496(class_2561.method_43471("tooltips.touhou_little_maid.film.no_data.desc"));
        }
    }

    private static void removeMaidSomeData(class_2487 nbt) {
        nbt.method_10551(EntityMaid.MAID_BACKPACK_TYPE);
        nbt.method_10551(EntityMaid.MAID_INVENTORY_TAG);
        nbt.method_10551(EntityMaid.MAID_BAUBLE_INVENTORY_TAG);
        nbt.method_10551(EntityMaid.EXPERIENCE_TAG);
        nbt.method_10551("ArmorItems");
        nbt.method_10551("HandItems");
        nbt.method_10551("Leash");
        nbt.method_10551("Health");
        nbt.method_10551("HurtTime");
        nbt.method_10551("DeathTime");
        nbt.method_10551("HurtByTimestamp");
        nbt.method_10551("Pos");
        nbt.method_10551("Motion");
        nbt.method_10551("FallDistance");
        nbt.method_10551("Fire");
        nbt.method_10551("Air");
        nbt.method_10551("TicksFrozen");
        nbt.method_10551("HasVisualFire");
        nbt.method_10551("Passengers");
        nbt.method_10551("ActiveEffects");
    }

    @Override
    public boolean method_7886(class_1799 stack) {
        return true;
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1792.class_9635 worldIn, List<class_2561> tooltip, class_1836 flagIn) {
        if (stack.method_57824(InitDataComponent.MAID_INFO) == null) {
            tooltip.add(class_2561.method_43471("tooltips.touhou_little_maid.film.no_data.desc").method_27692(class_124.field_1079));
        }
    }
}
